@@ -35,4 +35,10 @@ class DescribeTTSConfigRequest(RpcRequest):
 		return self.get_query_params().get('InstanceId')
 
 	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+		self.add_query_param('InstanceId',InstanceId)
+
+	def get_InstanceOwnerId(self):
+		return self.get_query_params().get('InstanceOwnerId')
+
+	def set_InstanceOwnerId(self,InstanceOwnerId):
+		self.add_query_param('InstanceOwnerId',InstanceOwnerId)
\ No newline at end of file
