@@ -37,6 +37,12 @@ class EndDialogueRequest(RpcRequest):
 	def set_ConversationId(self,ConversationId):
 		self.add_query_param('ConversationId',ConversationId)
 
+	def get_HangUpParams(self):
+		return self.get_query_params().get('HangUpParams')
+
+	def set_HangUpParams(self,HangUpParams):
+		self.add_query_param('HangUpParams',HangUpParams)
+
 	def get_InstanceId(self):
 		return self.get_query_params().get('InstanceId')
 
