@@ -73,6 +73,12 @@ class ListConversationsRequest(RpcRequest):
 	def set_BeginTimeRightRange(self,BeginTimeRightRange):
 		self.add_query_param('BeginTimeRightRange',BeginTimeRightRange)
 
+	def get_IsSandBox(self):
+		return self.get_query_params().get('IsSandBox')
+
+	def set_IsSandBox(self,IsSandBox):
+		self.add_query_param('IsSandBox',IsSandBox)
+
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
 
